==> aws-solutions-constructs.aws-wafwebacl-apigateway-1.128.0.tar.gz: package/lib/index.d.ts <==
/**
 *  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from '@aws-cdk/aws-apigateway';
import * as waf from '@aws-cdk/aws-wafv2';
import { Construct } from '@aws-cdk/core';
/**
 * @summary The properties for the WafwebaclToApiGateway class.
 */
export interface WafwebaclToApiGatewayProps {
    /**
     * The existing API Gateway instance that will be protected with the WAF web ACL.
     */
    readonly existingApiGatewayInterface: api.IRestApi;
    /**
     * Existing instance of a WAF web ACL, an error will occur if this and props is set.
     */
    readonly existingWebaclObj?: waf.CfnWebACL;
    /**
     * Optional user-provided props to override the default props for the AWS WAF web ACL.
     *
     * @default - Default properties are used.
     */
    readonly webaclProps?: waf.CfnWebACLProps;
}
/**
 * @summary The WafwebaclToApiGateway class.
 */
export declare class WafwebaclToApiGateway extends Construct {
    readonly webacl: waf.CfnWebACL;
    readonly apiGateway: api.IRestApi;
    /**
     * @param scope - represents the scope for all the resources.
     * @param id - this is a a scope-unique id.
     * @param props - user provided props for the construct.
     * @summary Constructs a new instance of the WafwebaclToApiGateway class.
     * @access public
     */
    constructor(scope: Construct, id: string, props: WafwebaclToApiGatewayProps);
}

==> aws-solutions-constructs.aws-wafwebacl-apigateway-1.175.0.tar.gz: package/lib/index.d.ts <==
/**
 *  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from '@aws-cdk/aws-apigateway';
import * as waf from '@aws-cdk/aws-wafv2';
import { Construct } from '@aws-cdk/core';
/**
 * @summary The properties for the WafwebaclToApiGateway class.
 */
export interface WafwebaclToApiGatewayProps {
    /**
     * The existing API Gateway instance that will be protected with the WAF web ACL.
     */
    readonly existingApiGatewayInterface: api.IRestApi;
    /**
     * Existing instance of a WAF web ACL, an error will occur if this and props is set
     */
    readonly existingWebaclObj?: waf.CfnWebACL;
    /**
     * Optional user-provided props to override the default props for the AWS WAF web ACL.
     *
     * @default - Default properties are used.
     */
    readonly webaclProps?: waf.CfnWebACLProps;
}
/**
 * @summary The WafwebaclToApiGateway class.
 */
export declare class WafwebaclToApiGateway extends Construct {
    readonly webacl: waf.CfnWebACL;
    readonly apiGateway: api.IRestApi;
    /**
     * @summary Constructs a new instance of the WafwebaclToApiGateway class.
     * @param {cdk.App} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {WafwebaclToApiGatewayProps} props - user provided props for the construct.
     * @access public
     */
    constructor(scope: Construct, id: string, props: WafwebaclToApiGatewayProps);
}
